%bcond_with bootstrap

# build with boost
%bcond_without boost

%define major 120
%define glibmajor 8
%define qt5major 1
%define cppmajor 0
%define girmajor 0.18

%define libname		%mklibname %{name} %{major}
%define libnameglib	%mklibname %{name}-glib %{glibmajor}
%define libnameqt5	%mklibname %{name}-qt5_ %{qt5major}
%define libnamecpp	%mklibname %{name}-cpp %{cppmajor}
%define libnamedev	%mklibname -d %{name}
%define libnameglibdev	%mklibname -d %{name}-glib
%define libnameqt5dev	%mklibname -d %{name}-qt5
%define libnamecppdev   %mklibname -d %{name}-cpp
%define libnamegir	%mklibname %{name}-gir %{girmajor}

Name:		poppler
Summary: 	PDF rendering library
Group:		Publishing
Version:	24.04.0
Release:	%mkrel 1
License:	GPLv2+
URL:		https://poppler.freedesktop.org
Source:		https://poppler.freedesktop.org/%{name}-%{version}.tar.xz
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(cairo-ft)
BuildRequires:	pkgconfig(cairo-pdf)
BuildRequires:	pkgconfig(cairo-ps)
BuildRequires:	pkgconfig(cairo-svg)
BuildRequires:	pkgconfig(fontconfig)
BuildRequires:	pkgconfig(freetype2)
%if ! %{with bootstrap}
BuildRequires:	pkgconfig(gdk-pixbuf-2.0)
BuildRequires:	pkgconfig(gio-2.0)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gobject-2.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  gtk-doc
BuildRequires:	python3
%endif
BuildRequires:	pkgconfig(lcms2)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(nss)
%if ! %{with bootstrap}
BuildRequires:	pkgconfig(Qt5Core) >= 5.0.0
BuildRequires:	pkgconfig(Qt5Gui) >= 5.0.0
BuildRequires:	pkgconfig(Qt5Test) >= 5.0.0
BuildRequires:	pkgconfig(Qt5Widgets) >= 5.0.0
BuildRequires:	pkgconfig(Qt5Xml) >= 5.0.0
%endif
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libopenjp2)
BuildRequires:	pkgconfig(poppler-data)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:	gettext-devel
BuildRequires:	cmake
BuildRequires:	ninja
%if %{with boost}
BuildRequires:  boost-devel
%endif
Provides:	xpdf-tools
Provides:	pdftohtml

%description
Poppler is a PDF rendering library based on the xpdf-3.0 code base.

%package -n	%{libname}
Summary:	PDF rendering library
Group:          System/Libraries
Requires:	poppler-data
Obsoletes: lib64poppler116

%description -n	%{libname}
Poppler is a PDF rendering library based on the xpdf-3.0 code base.

%package -n	%{libnamedev}
Summary:	Development files for %{name}
Group:		Development/Libraries
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
%if %{with boost}
# /usr/include/poppler/splash/SplashXPathScanner.h:31:10: fatal error:
# boost/container/small_vector.hpp: No such file or directory
Requires:	boost-devel
%endif

%description -n	%{libnamedev}
Development files for %{name}

%package -n	%{libnamecpp}
Summary:	PDF rendering library - C++ backend
Group:          System/Libraries

%description -n	%{libnamecpp}
Poppler is a PDF rendering library based on the xpdf-3.0 code base.
This is the C++ backend version.

%package -n	%{libnameqt5dev}
Summary: 	Development files for %{name}-qt5
Group:		Development/Libraries
Provides:	%{name}-qt5-devel = %{version}-%{release}
Requires:	%{libnameqt5} = %{version}-%{release}
Requires:	%{libnamedev} = %{version}-%{release}

%description -n	%{libnameqt5dev}
Development files for %{name}-qt5.

%package -n	%{libnameqt5}
Summary: 	PDF rendering library - Qt5 backend
Group:		System/Libraries

%description -n	%{libnameqt5}
Poppler is a PDF rendering library based on the xpdf-3.0 code base.
This is the Qt5 backend version.

%package -n	%{libnameglib}
Summary:	PDF rendering library - glib binding
Group:		System/Libraries

%description -n	%{libnameglib}
Poppler is a PDF rendering library based on the xpdf-3.0 code base.

%package -n	%{libnameglibdev}
Summary:	Development files for %{name}'s glib binding
Group:		Development/Libraries
Provides:	%{name}-glib-devel = %{version}-%{release}
Requires:	%{libnameglib} = %{version}-%{release}
Requires:	%{libnamedev} = %{version}-%{release}

%description -n	%{libnameglibdev}
Development files for %{name}'s glib binding.

%package -n	%{libnamecppdev}
Summary:	Development files for %{name}-cpp
Group:		Development/Libraries
Provides:	%{name}-cpp-devel = %{version}-%{release}
Requires:	%{libnamecpp} = %{version}-%{release}
Requires:	%{libnamedev} = %{version}-%{release}

%description -n	%{libnamecppdev}
Development files for %{name}-cpp.

%prep
%setup -q
%autopatch -p1

#dont change library major
sd "136" "120" CMakeLists.txt

%build
%if ! %{with bootstrap}
export MOCQT5=%{_qt5_bindir}/moc
%endif

%cmake \
  -DBUILD_GTK_TESTS=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON} \
  -DBUILD_QT5_TESTS=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON} \
  -DENABLE_CMS=lcms2 \
  -DENABLE_DCTDECODER=libjpeg \
  -DENABLE_LIBOPENJPEG=openjpeg2 \
  -DENABLE_QT5=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON} \
  -DENABLE_UNSTABLE_API_ABI_HEADERS=ON \
  -DENABLE_GTK_DOC=NO \
  -DENABLE_GPGME=OFF \
 -DENABLE_QT6=OFF

%cmake_build

%install
%cmake_install

cp -a %{_vpath_builddir}/config.h %{buildroot}%{_includedir}/poppler/
rm -rf %buildroot/%{_datadir}/locale/ca/LC_MESSAGES/pdfsig.mo

%files
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/libpoppler.so.%{major}*
%{_libdir}/girepository-1.0/Poppler-%{girmajor}.typelib

%files -n %{libnamedev}
%{_libdir}/libpoppler.so
%dir %{_includedir}/poppler/
%{_includedir}/poppler/config.h
%{_includedir}/poppler/[A-Z]*
%{_includedir}/poppler/fofi
%{_includedir}/poppler/goo
%{_includedir}/poppler/splash
%{_includedir}/poppler/poppler_private_export.h
%{_includedir}/poppler/poppler-config.h
%{_libdir}/pkgconfig/poppler.pc

%files -n %{libnameglib}
%{_libdir}/libpoppler-glib.so.%{glibmajor}*

%files -n %{libnameglibdev}
%{_libdir}/libpoppler-glib.so
%{_libdir}/pkgconfig/poppler-glib.pc
%{_includedir}/poppler/glib/
%{_datadir}/gir-1.0/Poppler-%{girmajor}.gir

%if ! %{with bootstrap}
%files -n %{libnameqt5dev}
%{_includedir}/poppler/qt5/
%{_libdir}/pkgconfig/poppler-qt5.pc
%{_libdir}/libpoppler-qt5.so

%files -n %{libnameqt5}
%{_libdir}/libpoppler-qt5.so.%{qt5major}*
%endif

%files -n %{libnamecpp}
%{_libdir}/libpoppler-cpp.so.%{cppmajor}*

%files -n %{libnamecppdev}
%{_libdir}/libpoppler-cpp.so
%{_libdir}/pkgconfig/poppler-cpp.pc
%{_includedir}/poppler/cpp


%changelog
* Tue Apr 02 2024 tex - 24.04.0-1pclos2024
- new version

* Mon Mar 04 2024 tex - 24.03.0-1pclos2024
- new version

* Wed Jan 03 2024 tex - 24.01.0-1pclos2024
- new version

* Sun Dec 03 2023 tex - 23.12.0-1pclos2023
- new version

* Sat Nov 04 2023 tex - 23.11.0-1pclos2023
- new version

* Tue Oct 03 2023 tex - 23.10.0-1pclos2023
- new version

* Wed Sep 06 2023 tex - 23.09.0-1pclos2023
- new version

* Tue Aug 08 2023 tex - 23.08.0-1pclos2023
- new version

